import numpy
from model import *
from triangle import *
from setmask import *
from parameterize import *
from setflowequation import *
from EnumDefinitions import *
from solve import *
from MatlabFuncs import *

md=triangle(model(),'../Exp/Square.exp',150000.)
md=setmask(md,'all','')
md=parameterize(md,'../Par/SquareShelf.py')
md.extrude(3,1.)
md=setflowequation(md,'HO','all')
md.cluster=generic('name',oshostname(),'np',3)

md.timestepping.time_step=1.
md.settings.output_frequency=1
md.timestepping.final_time=4.

#Set up transient
smb=numpy.ones((md.mesh.numberofvertices,1))*3.6
smb=numpy.hstack((smb,smb*-1.))

md.surfaceforcings=SMBmeltcomponents();
md.surfaceforcings.accumulation=numpy.vstack((smb, [1.5,3.]));
md.surfaceforcings.evaporation=numpy.vstack((smb/2, [1.5,3.]));
md.surfaceforcings.melt=numpy.vstack((smb/2, [1.5,3.]));
md.surfaceforcings.refreeze=numpy.vstack((smb, [1.5,3.]));
md.transient.isthermal=False

md=solve(md,TransientSolutionEnum())

#Fields and tolerances to track changes
field_names=['Vx1','Vy1','Vel1','Pressure1','Bed1','Surface1','Thickness1','SurfaceforcingsMassBalance1', \
	'Vx2','Vy2','Vel2','Pressure2','Bed2','Surface2','Thickness2','SurfaceforcingsMassBalance2', \
	'Vx3','Vy3','Vel3','Pressure3','Bed3','Surface3','Thickness3','SurfaceforcingsMassBalance3', \
	'Vx4','Vy4','Vel4','Pressure4','Bed4','Surface4','Thickness4','SurfaceforcingsMassBalance4']
field_tolerances=[1e-09,1e-09,1e-10,1e-10,1e-10,1e-10,1e-10,1e-10,\
	1e-09,1e-09,1e-10,1e-10,1e-10,1e-10,1e-10,1e-10,\
	1e-09,1e-09,1e-10,1e-10,1e-10,1e-10,1e-10,1e-10,\
	1e-09,1e-09,1e-10,1e-10,1e-10,1e-10,1e-10,1e-10]
field_values=[\
	md.results.TransientSolution[0].Vx,\
	md.results.TransientSolution[0].Vy,\
	md.results.TransientSolution[0].Vel,\
	md.results.TransientSolution[0].Pressure,\
	md.results.TransientSolution[0].Base,\
	md.results.TransientSolution[0].Surface,\
	md.results.TransientSolution[0].Thickness,\
	md.results.TransientSolution[0].SurfaceforcingsMassBalance,\
	md.results.TransientSolution[1].Vx,\
	md.results.TransientSolution[1].Vy,\
	md.results.TransientSolution[1].Vel,\
	md.results.TransientSolution[1].Pressure,\
	md.results.TransientSolution[1].Base,\
	md.results.TransientSolution[1].Surface,\
	md.results.TransientSolution[1].Thickness,\
	md.results.TransientSolution[1].SurfaceforcingsMassBalance,\
	md.results.TransientSolution[2].Vx,\
	md.results.TransientSolution[2].Vy,\
	md.results.TransientSolution[2].Vel,\
	md.results.TransientSolution[2].Pressure,\
	md.results.TransientSolution[2].Base,\
	md.results.TransientSolution[2].Surface,\
	md.results.TransientSolution[2].Thickness,\
	md.results.TransientSolution[2].SurfaceforcingsMassBalance,\
	md.results.TransientSolution[3].Vx,\
	md.results.TransientSolution[3].Vy,\
	md.results.TransientSolution[3].Vel,\
	md.results.TransientSolution[3].Pressure,\
	md.results.TransientSolution[3].Base,\
	md.results.TransientSolution[3].Surface,\
	md.results.TransientSolution[3].Thickness,\
	md.results.TransientSolution[3].SurfaceforcingsMassBalance,\
	]
